@@ -35,7 +35,9 @@
 using namespace KDAV;
 
 DavCollectionsFetchJob::DavCollectionsFetchJob(const DavUrl &url, QObject *parent)
-    : DavJobBase(parent), mUrl(url), mSubJobCount(0)
+    : DavJobBase(parent)
+    , mUrl(url)
+    , mSubJobCount(0)
 {
 }
 
@@ -122,9 +124,10 @@ void DavCollectionsFetchJob::principalFetchFinished(KJob *job)
 void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
 {
     KIO::DavJob *davJob = qobject_cast<KIO::DavJob *>(job);
-    const int responseCode = davJob->queryMetaData(QStringLiteral("responsecode")).isEmpty() ?
-                             0 :
-                             davJob->queryMetaData(QStringLiteral("responsecode")).toInt();
+    const QString responseCodeStr = davJob->queryMetaData(QStringLiteral("responsecode"));
+    const int responseCode = responseCodeStr.isEmpty()
+                             ? 0
+                             : responseCodeStr.toInt();
 
     // KIO::DavJob does not set error() even if the HTTP status code is a 4xx or a 5xx
     if (davJob->error() || (responseCode >= 400 && responseCode < 600)) {
@@ -229,7 +232,6 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
 
             QDomElement responseElement = Utils::firstChildElementNS(responsesElement, QStringLiteral("DAV:"), QStringLiteral("response"));
             while (!responseElement.isNull()) {
-
                 QDomElement propstatElement;
 
                 // check for the valid propstat, without giving up on first error
@@ -301,7 +303,14 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
                 if (!colorElement.isNull()) {
                     QString colorValue = colorElement.text();
                     if (QColor::isValidColor(colorValue)) {
-                        color.setNamedColor(colorValue);
+                        // Color is either #RRGGBBAA or #RRGGBB but QColor expects #AARRGGBB
+                        // so we put the AA in front if the string's length is 9.
+                        if (colorValue.size() == 9) {
+                            QString fixedColorValue = QStringLiteral("#") + colorValue.mid(7, 2) + colorValue.mid(1, 6);
+                            color.setNamedColor(fixedColorValue);
+                        } else {
+                            color.setNamedColor(colorValue);
+                        }
                     }
                 }
 
@@ -345,4 +354,3 @@ void DavCollectionsFetchJob::subjobFinished()
         emitResult();
     }
 }
-
