@@ -28,7 +28,9 @@
 using namespace KDAV;
 
 DavItemDeleteJob::DavItemDeleteJob(const DavItem &item, QObject *parent)
-    : DavJobBase(parent), mItem(item), mFreshResponseCode(-1)
+    : DavJobBase(parent)
+    , mItem(item)
+    , mFreshResponseCode(-1)
 {
 }
 
@@ -58,9 +60,9 @@ void DavItemDeleteJob::davJobFinished(KJob *job)
     KIO::DeleteJob *deleteJob = qobject_cast<KIO::DeleteJob *>(job);
 
     if (deleteJob->error() && deleteJob->error() != KIO::ERR_NO_CONTENT) {
-        const int responseCode = deleteJob->queryMetaData(QStringLiteral("responsecode")).isEmpty() ?
-                                 0 :
-                                 deleteJob->queryMetaData(QStringLiteral("responsecode")).toInt();
+        const int responseCode = deleteJob->queryMetaData(QStringLiteral("responsecode")).isEmpty()
+                                 ? 0
+                                 : deleteJob->queryMetaData(QStringLiteral("responsecode")).toInt();
 
         if (responseCode != 404 && responseCode != 410) {
             setLatestResponseCode(responseCode);
@@ -92,4 +94,3 @@ void DavItemDeleteJob::conflictingItemFetched(KJob *job)
 
     emitResult();
 }
-
