@@ -22,7 +22,8 @@
 
 using namespace KDAV;
 
-class DavJobBasePrivate {
+class DavJobBasePrivate
+{
 public:
     DavJobBasePrivate();
 
@@ -45,7 +46,7 @@ DavJobBase::~DavJobBase()
 {
 }
 
-unsigned int DavJobBase::latestResponseCode() const
+int DavJobBase::latestResponseCode() const
 {
     return d->mLatestResponseCode;
 }
@@ -96,14 +97,14 @@ bool DavJobBase::hasConflict() const
     return latestResponseCode() == 412;
 }
 
-void DavJobBase::setLatestResponseCode(unsigned int code)
+void DavJobBase::setLatestResponseCode(int code)
 {
     d->mLatestResponseCode = code;
 }
 
 Error DavJobBase::davError() const
 {
-    return Error((KDAV::ErrorNumber)error(), d->mLatestResponseCode, d->mInternalErrorText, d->mJobErrorCode);
+    return Error(static_cast<KDAV::ErrorNumber>(error()), d->mLatestResponseCode, d->mInternalErrorText, d->mJobErrorCode);
 }
 
 void DavJobBase::setJobErrorText(const QString &errorText)
@@ -111,7 +112,7 @@ void DavJobBase::setJobErrorText(const QString &errorText)
     d->mInternalErrorText = errorText;
 }
 
-void DavJobBase::setJobError(unsigned int jobErrorCode)
+void DavJobBase::setJobError(int jobErrorCode)
 {
     d->mJobErrorCode = jobErrorCode;
 }
